@@ -452,6 +452,10 @@ class DailyDevice(db.Model):
 
 class UsageType(db.Model):
     name = db.CharField(verbose_name=_("name"), max_length=255, unique=True)
+    symbol = db.CharField(verbose_name=_("symbol"),
+        max_length=255,
+        default="",
+    )
     average = db.BooleanField(
         verbose_name=_("Average the values over multiple days"),
         default=False,
@@ -500,7 +504,7 @@ class UsagePrice(db.Model):
 
 
 class DailyUsage(db.Model):
-    date = db.DateField()
+    date = db.DateTimeField()
     pricing_venture = db.ForeignKey(
         Venture,
         verbose_name=_("venture"),
@@ -518,12 +522,13 @@ class DailyUsage(db.Model):
         on_delete=db.SET_NULL,
     )
     value = db.FloatField(verbose_name=_("value"), default=0)
+    total = db.FloatField(verbose_name=_("total usage"), default=0)
     type = db.ForeignKey(UsageType, verbose_name=_("type"))
 
     class Meta:
         verbose_name = _("daily usage")
         verbose_name_plural = _("daily usages")
-        unique_together = ('date', 'pricing_device', 'type')
+        unique_together = ('date', 'pricing_device', 'type', 'pricing_venture')
         ordering = ('pricing_device', 'type', 'date')
 
     def __unicode__(self):
